#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-HIzXdVNetB5z6T1SnAv7U
key:                  http-date-0.0.11-HIzXdVNetB5z6T1SnAv7U
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  95070ac10208283b1ece41ccac41779b
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-date-0.0.11
hs-libraries:         HShttp-date-0.0.11-HIzXdVNetB5z6T1SnAv7U
depends:
    array-0.5.4.0 attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib
    base-4.14.2.0 bytestring-0.10.12.0 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

